#!/usr/bin/env python

# <one line to give the program's name and a brief idea of what it does.>
# Copyright (C) 2020 lynnesbian

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import requests, gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk, Gio, Gdk

import functions
from listing import YahooAuctionsItem
from settings import BuypeebSettings

import json, sys
from os import path

isWindows = sys.platform.startswith('win')

if isWindows:
	settingsLocation = path.join(os.getenv("APPDATA"), "Lynnear Software", "bypeeb")
else:
	settingsLocation = path.expanduser("~/.config/Lynnear Software/buypeeb/") # dotfiles in ~ need to die. begone dot

class BuypeebApp:
	def __init__(self):
		self.app = Gtk.Application.new('com.lynnearsoftware.buypeeb', 0)
		self.app.connect('startup', self.startup)
		self.app.connect('activate', self.activate)
		self.app.connect('shutdown', self.shutdown)
		self.window = None
		self.settings = BuypeebSettings(settingsLocation)
		self.builder = None

	def run(self, argv):
		self.app.run(argv)

	def startup(self, app):
		builder = Gtk.Builder()
		builder.add_from_string(open(path.join(path.dirname(__file__), "ui/main.glade"), 'r').read())
		builder.connect_signals(self)
		wndMain = builder.get_object('wndMain')
		self.window = wndMain
		self.builder = builder
		app.add_window(self.window)

		self.settings.load()

	def activate(self, app):
		self.window.show_all()

	def shutdown(self, app):
		self.settings.save()
		self.app.quit()

	def msgBox(self, title, text, form = Gtk.MessageType.WARNING):
		msgbox = Gtk.MessageDialog(self.window, 0, form, Gtk.ButtonsType.OK, title)
		msgbox.format_secondary_text(text)
		response = msgbox.run()
		msgbox.destroy()
		return response

	def entryBox(self, title, text, allow_cancel = True):
		# thanks to https://ardoris.wordpress.com/2008/07/05/pygtk-text-entry-dialog/
		entrybox = Gtk.MessageDialog(
			parent = self.window,
			modal = True,
			destroy_with_parent = True,
			message_type = Gtk.MessageType.QUESTION,
			buttons = Gtk.ButtonsType.OK_CANCEL if allow_cancel else Gtk.ButtonsType.OK,
			title = title
		)

		entrybox.set_markup(text)
		entry = Gtk.Entry()
		entry.connect("activate", self.entryBoxResponse, entrybox, Gtk.ResponseType.OK) # allow for pressing enter instead of clicking OK

		entrybox.vbox.pack_end(entry, True, True, 0)
		entrybox.show_all()

		response = entrybox.run()
		text = entry.get_text()
		entrybox.destroy()
		if response:
			return text
		else:
			# user clicked cancel
			return False

	def entryBoxResponse(self, widget, entrybox, response):
		entrybox.response(response)

	def btnAddClicked(self, widget):
		print(self.entryBox("Add URL", "Enter the URL of the item you want to add."))

	def btnQuitClicked(self, widget):
		prompt = Gtk.MessageDialog(self.window, 0, Gtk.MessageType.QUESTION, Gtk.ButtonsType.OK_CANCEL, "Really quit?")
		prompt.format_secondary_text("Are you sure you want to quit buypeeb?")
		response = prompt.run()
		if response:
			self.shutdown(self)

if __name__ == '__main__':
	app = BuypeebApp()
	app.run(sys.argv)
